<?php

class DispletRetsIdxLeadManagerPageModel extends DispletRetsIdxAdminPagesModel {
	protected static function build_model() {
		self::get_defaults();
		self::maybe_get_pagination();
		self::maybe_get_user_args();
		self::maybe_get_leads();
		self::maybe_get_lead();
	}

	private static function get_defaults() {
		self::$_model = array_merge( self::$_model, array(
			'is_admin' => current_user_can( 'manage_options' ),
			'is_single' => !empty( $_GET['user_id'] ) ? true : false,
			'lead_manager_page_url' => admin_url( 'admin.php?page=' . self::$_slugs['lead_manager_page'] ),
			'options' => self::$_options,
			'property_details_page_url' => get_permalink( self::$_options['property_details_page_id'] ),
			'search_results_page_url' => get_permalink( self::$_options['search_results_page_id'] ),
			'user_has_address' => false,
			'user_id' => $_GET['user_id'],
		) );
	}

	private static function maybe_get_leads() {
		if ( ! self::$_model['is_single'] ) {
			self::$_model['leads'] = get_users( self::$_model['user_args'] );
			self::$_model['count'] = count( self::$_model['leads'] );
		}
	}

	private function maybe_get_lead() {
		if ( self::$_model['is_single'] ) {
			self::$_model['lead'] = get_user_by( 'id', self::$_model['user_id'] );
		}
	}

	private function maybe_get_opened_emails() {
		if ( self::$_model['is_single'] && !empty( self::$_model['lead']->displet_api_user_id ) ) {

		}
	}

	private static function maybe_get_user_args() {
		if ( ! self::$_model['is_single'] ) {
			self::$_model['user_args'] = array(
				'role' => self::$_roles['lead'],
				'orderby' => 'registered',
				'order' => 'DESC',
				'number' => 25,
				'offset' => 25 * ( self::$_model['page'] - 1 ),
			);
			if ( !current_user_can( 'manage_options' ) ) {
				self::$_model['user_args']['meta_key'] = 'displet_agent_id';
				self::$_model['user_args']['meta_value'] = get_current_user_id();
			}
			$meta_query = array();
			if ( !empty( $_GET['user_name'] ) ) {
				$meta_query[] = array(
					'key' => 'nickname',
					'value' => $_GET['user_name'],
					'compare' => 'LIKE'
				 );
			}
			if ( !empty( $_GET['user_email'] ) ) {
				self::$_model['user_args']['search'] = '*' . $_GET['user_email'] . '*';
			}
			if ( !empty( $_GET['user_phone'] ) ) {
				$meta_query[] = array(
					'key' => 'displet_phone',
					'value' => $_GET['user_phone'],
					'compare' => 'LIKE'
				 );
			}
			if ( !empty( $_GET['logged_in_since'] ) ) {
				$meta_query[] = array(
					'key' => 'displet_last_login',
					'value' => strtotime( $_GET['logged_in_since'] ),
					'compare' => '>=',
					'type' => 'numeric'
				 );
			}
			if ( !empty( $_GET['has_phone'] ) ) {
				$meta_query[] = array(
					'key' => 'displet_phone',
					'value' => '',
					'compare' => '!='
				 );
				$meta_query[] = array(
					'key' => 'displet_phone',
					'value' => '(     )    -    ',
					'compare' => '!='
				 );
			}
			if ( !empty( $_GET['min_logins'] ) ) {
				$meta_query[] = array(
					'key' => 'displet_logins_count',
					'value' => preg_replace( '/[^0-9]/', '', $_GET['min_logins'] ),
					'compare' => '>=',
					'type' => 'numeric'
				 );
			}
			if ( !empty( $_GET['min_saved_properties'] ) ) {
				$meta_query[] = array(
					'key' => 'displet_saved_properties_count',
					'value' => preg_replace( '/[^0-9]/', '', $_GET['min_saved_properties'] ),
					'compare' => '>=',
					'type' => 'numeric'
				 );
			}
			if ( !empty( $_GET['min_saved_searches'] ) ) {
				$meta_query[] = array(
					'key' => 'displet_user_hashes_count',
					'value' => preg_replace( '/[^0-9]/', '', $_GET['min_saved_searches'] ),
					'compare' => '>=',
					'type' => 'numeric'
				 );
			}
			if ( !empty( $_GET['min_showing_requests'] ) ) {
				$meta_query[] = array(
					'key' => 'displet_property_inquiries_count',
					'value' => preg_replace( '/[^0-9]/', '', $_GET['min_showing_requests'] ),
					'compare' => '>=',
					'type' => 'numeric'
				 );
			}
			if ( !empty( $_GET['zip_mode'] ) ) {
				$meta_query[] = array(
					'key' => 'displet_zip_mode',
					'value' => $_GET['zip_mode'],
					'compare' => '=',
					'type' => 'numeric'
				 );
			}
			if ( !empty( $_GET['mean_price_min'] ) ) {
				$meta_query[] = array(
					'key' => 'displet_mean_price',
					'value' => preg_replace( '/[^0-9]/', '', $_GET['mean_price_min'] ),
					'compare' => '>=',
					'type' => 'numeric'
				 );
			}
			if ( !empty( $_GET['mean_price_max'] ) ) {
				$meta_query[] = array(
					'key' => 'displet_mean_price',
					'value' => preg_replace( '/[^0-9]/', '', $_GET['mean_price_max'] ),
					'compare' => '<=',
					'type' => 'numeric'
				 );
			}
			if ( !empty( $_GET['mean_square_feet_min'] ) ) {
				$meta_query[] = array(
					'key' => 'displet_mean_square_feet',
					'value' => preg_replace( '/[^0-9]/', '', $_GET['mean_square_feet_min'] ),
					'compare' => '>=',
					'type' => 'numeric'
				 );
			}
			if ( !empty( $_GET['mean_square_feet_max'] ) ) {
				$meta_query[] = array(
					'key' => 'displet_mean_square_feet',
					'value' => preg_replace( '/[^0-9]/', '', $_GET['mean_square_feet_max'] ),
					'compare' => '<=',
					'type' => 'numeric'
				 );
			}
			if ( !empty( $meta_query ) ) {
				self::$_model['user_args']['meta_query'] = $meta_query;
			}
		}
	}

	private static function maybe_get_pagination() {
		if ( ! self::$_model['is_single'] ) {
			$unpaged_url = preg_replace( '/&pagenum=( \d+ )/', '', $_SERVER["REQUEST_URI"] );
			self::$_model['page'] = !empty( $_GET['pagenum'] ) ? intval( $_GET['pagenum'] ) : 1;
			self::$_model['previous_url'] = $unpaged_url . '&pagenum=' . ( self::$_model['page'] - 1 );
			self::$_model['next_url'] = $unpaged_url . '&pagenum=' . ( self::$_model['page'] + 1 );
		}
	}
}

?>